<?php
/**
* @package Protect for WooCommerce
* @author  Protect, Inc.
* @license Proprietary
* @link    https://protect.inc
**/

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Woo_Protect_Config {

    private $_protect;
    /**
    * Constructor
    **/
    function __construct() {
        $this->_protect = Woo_Protect_Base::getInstance();
        add_action( 'wp_enqueue_scripts', array( $this, 'scripts' ) );
    }

    /**
    * Initialize Scripts & Params
    **/
    function scripts() {

        // Local JS & CSS
        wp_register_style( 'protect-css', WC_PROTECT_URL . 'frontend/assets/css/protect.css' );
        wp_register_script( 'protect-js', WC_PROTECT_URL . 'frontend/assets/js/protect.js', array('jquery'), null, true );

        // JS Params
        $wcCart         = WC()->cart;
        $wcSession      = WC()->session;
        $wcShipping     = WC()->session->get( 'chosen_shipping_methods' );
        $apiUrl         = get_option( 'wc_protect_api_url' );
        $scgUrl         = get_option( 'wc_protect_scg_url' );
        $publicKey      = get_option( 'wc_protect_public_key' );
        $decimal        = get_option( 'woocommerce_price_decimal_sep' );
        $customer       = $wcSession->get('customer');

        // Four Protect vars
        $price          = $this->getProtectCartFee() ? $this->getProtectCartFee() : 0.99;
        $subtotal       = $this->_protect->getSubtotal();
        $discount       = $this->_protect->getDiscount();
        $checked        = $this->hasProtectCartFee();
        $userUnchecked  = $wcSession->get('protectUnchecked');

        // This object stores the previous four Protect var values used to compare old and new state.
        // This object is removed completely when the fee is removed from the cart.
        $protect        = $wcSession->get('protect') ? $wcSession->get('protect') : [];

        $pricing        = $this->_protect->getProtectPricing($subtotal,$discount);
        $price          = isset( $pricing->price ) ? $pricing->price : $price;
        $autocheck      = isset( $pricing->checked_by_default ) ? $pricing->checked_by_default : true;
        $forcecheck     = isset( $pricing->checkbox_always_checked ) ? $pricing->checkbox_always_checked : false;
        $enabled        = isset( $pricing->enabled ) ? $pricing->enabled : true;

        // Update the fees
        if ( $price && WC()->cart && ($checked || $autocheck || $forcecheck) && (!$userUnchecked || $forcecheck) ) {
            // Remove existing Protect fee
            $this->removeProtectCartFee();
            // Add new Protect Fee
            if ( $enabled ) {
                $this->addProtectCartFee($price);
            }
        }

        wp_localize_script( 'protect-js', 'ProtectWC', array(
            // Ajax Calls
            'ajaxUrl'       => admin_url( 'admin-ajax.php' ),
            'nonce_add'     => wp_create_nonce('protect_add'),
            'nonce_rem'     => wp_create_nonce('protect_remove'),
            'nonce_cart'    => wp_create_nonce('protect_cart'),

            // Session Data
            'cart'          => $wcCart,
            'shipping'      => $wcShipping,
            'session'       => $wcSession,
            'customer'      => $customer,

            // Protect Values
            'checked'       => $checked,
            'discount'      => $discount,
            'subtotal'      => $subtotal,
            'price'         => $price,
            'forced'        => $forcecheck,

            // Previous Protect Values
            'protect'       => $protect,

            // Protect API
            'apiUrl'        => $apiUrl,
            'scgUrl'        => $scgUrl,
            'apiKey'        => $publicKey,

            // Helper
            'currency'      => get_woocommerce_currency_symbol(),
            'isCart'        => is_cart(),
            'isCheckout'    => is_checkout(),
            'decimal'       => $decimal ? $decimal : '.',
        ) );

        // After performing comparisons, update the Protect var with latest values.
        $protect['price']       = $price;
        $protect['subtotal']    = $subtotal;
        $protect['discount']    = $discount;
        $protect['checked']     = $checked;
        $protect['forced']      = $forcecheck;

        // Update Session with latest Protect values
        $wcSession->set( 'protect', $protect );
    }



    function hasProtectCartFee() {
        if ($this->getProtectCartFee()) return true;
        return false;
    }

    function getProtectCartFee() {
        $fees = WC()->cart->get_fees();
        foreach ($fees as $key => $fee) {
            if ($fees[$key]->name === WC_PROTECT_FEE_LABEL) {
                return $fee->amount;
            }
        }
        return 0;
    }

    function addProtectCartFee($price) {
        $label = WC_PROTECT_FEE_LABEL;
        $isTaxable  = isset( $this->settings['wc_protect_is_taxable'] ) && $this->settings['wc_protect_is_taxable'] == 'yes' ? true : false;
        return WC()->cart->add_fee( $label, $price, $isTaxable, '' );
    }

    function removeProtectCartFee() {
        return $this->removeCartFee(WC_PROTECT_FEE_LABEL);
    }

    function removeCartFee( $name ) {
        $found  = 0;
        $fees   = WC()->cart->get_fees();
        foreach ($fees as $key => $fee) {
            if ($fees[$key]->name === $name ) {
                unset($fees[$key]);
                $found = $fee;
                break;
            }
        }
        if ($found) WC()->cart->fees_api()->set_fees($fees);
        return $found;
    }

}
?>
